@@ -25,7 +25,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <getopt.h>
+
+#ifdef NO_GETOPT
+  /* use replacement */
+  #include "compat/getopt.h"
+#else
+  #include <getopt.h>
+#endif
 
 #include "cmdline.h"
 
