@@ -252,7 +252,7 @@ static int width_of_partial(char *partial)
  */
 int Barcode_ean_encode(struct Barcode_Item *bc)
 {
-    static char text[16];
+    static char text[24];
     static char partial[256];
     static char textinfo[256];
     char *mirror, *ptr1, *ptr2, *tptr = textinfo; /* where text is written */
@@ -261,7 +261,7 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
     int i, xpos, checksum;
 
     if (!bc->ascii) {
-	bc->error = ENODATA;
+	bc->error = EINVAL;
 	return -1;
     }
     if (!bc->encoding) {
@@ -323,9 +323,11 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 
 	strcpy(partial, guard[0]);
 	if (encoding == EAN13 || encoding == ISBN) { /* The first digit */
-	    tptr += sprintf(tptr,"0:12:%c ",text[0]);
+	    sprintf(tptr,"0:12:%c ",text[0]);
+	    tptr += strlen(tptr);
 	    partial[0] = '9'; /* extra space for the digit */
-	}
+	} else if (encoding == UPCA)
+	    partial[0] = '9'; /* UPC has one digit before the symbol, too */
 	xpos = width_of_partial(partial);
 	mirror = ean_mirrortab[text[0]-'0'];
 
@@ -341,7 +343,20 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 		ptr1[2] = ptr2[1];
 		ptr1[3] = ptr2[0];
 	    }
-	    tptr += sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    /*
+	     * Write the ascii digit. UPC has a special case
+	     * for the first digit, which is out of the bars
+	     */
+	    if (encoding == UPCA && i==1) {
+		sprintf(tptr, "0:10:%c ", text[i]);
+		tptr += strlen(tptr);
+		ptr1[1] += 'a'-'1'; /* bars are long */
+		ptr1[3] += 'a'-'1';
+	    } else {
+		sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+		tptr += strlen(tptr);
+	    }
+	    /* count the width of the symbol */
 	    xpos += 7; /* width_of_partial(ptr2) */
 	}
 
@@ -353,7 +368,19 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 	    ptr1 = partial + strlen(partial); /* target */
 	    ptr2 =  digits[text[i]-'0'];      /* source */
 	    strcpy(ptr1, ptr2);
-	    tptr += sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    /*
+	     * Ascii digit. Once again, UPC has a special
+	     * case for the last digit
+	     */
+	    if (encoding == UPCA && i==12) {
+		sprintf(tptr, "%i:10:%c ", xpos+13, text[i]);
+		tptr += strlen(tptr);
+		ptr1[0] += 'a'-'1'; /* bars are long */
+		ptr1[2] += 'a'-'1';
+	    } else {
+		sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+		tptr += strlen(tptr);
+	    }
 	    xpos += 7; /* width_of_partial(ptr2) */
 	}
 	tptr[-1] = '\0'; /* overwrite last space */
@@ -399,7 +426,8 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 		    ptr1[3] = ptr2[0];
 		}
 		/* and the text */
-		tptr += sprintf(tptr, " %i:12:%c", xpos, text[i]);
+		sprintf(tptr, " %i:12:%c", xpos, text[i]);
+		tptr += strlen(tptr);
 		xpos += 7; /* width_of_partial(ptr2) */
 	    }
 	}
@@ -423,7 +451,8 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 		ptr1[2] = ptr2[1];
 		ptr1[3] = ptr2[0];
 	    }
-	    tptr += sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    tptr += strlen(tptr);
 	    xpos += 7; /* width_of_partial(ptr2) */
 	}
 	tptr[-1] = '\0'; /* overwrite last space */
@@ -441,7 +470,8 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 	/* left part */
 	for (i=0;i<4;i++) {      
 	    strcpy(partial + strlen(partial), digits[text[i]-'0']);
-	    tptr += sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    tptr += strlen(tptr);
 	    xpos += 7; /* width_of_partial(digits[text[i]-'0' */
 	}
 	strcat(partial, guard[1]); /* middle */
@@ -450,7 +480,8 @@ int Barcode_ean_encode(struct Barcode_Item *bc)
 	/* right part */
 	for (i=4;i<8;i++) {      
 	    strcpy(partial + strlen(partial), digits[text[i]-'0']);
-	    tptr += sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    sprintf(tptr, "%i:12:%c ", xpos, text[i]);
+	    tptr += strlen(tptr);
 	    xpos += 7; /* width_of_partial(digits[text[i]-'0' */
 	}
 	tptr[-1] = '\0'; /* overwrite last space */
